%define %teuchos_rcp_docstring
"
PyTrilinos.Teuchos.RCP is a special PyTrilinos module designed to
provide access to RCP methods for PyTrilinos variables that are
stored internally via Teuchos::RCP reference counted pointers.

Inspired by the python function sys.getrefcount(object), this module
provides a number of Teuchos::RCP methods as python functions that
take a PyTrilinos object as their argument. These functions include:

    * is_null(obj)        - Return True if underlying pointer is NULL
    * is_valid_ptr(obj)   - Return True if underlying pointer is valid
    * has_ownership(obj)  - Return True if this RCP owns the object
    * strong_count(obj)   - Return the strong reference count
    * weak_count(obj)     - Return the weak reference count
    * total_count(obj)    - Return the total reference count
"
%enddef

%define %teuchos_import_code
"
from . import RCP
"
%enddef

%module(package       = "PyTrilinos.Teuchos",
        moduleinclude = %teuchos_import_code,
        docstring     = %teuchos_rcp_docstring) RCP

%{
// Import the NumPy interface
#define NO_IMPORT_ARRAY
#include "numpy_include.hpp"

// Include the header files
#include "PyTrilinos_config.h"
#include "PyTrilinos_Teuchos_Headers.hpp"
#include "PyTrilinos_Epetra_Headers.hpp"
#include "PyTrilinos_TriUtils_Headers.hpp"
#include "PyTrilinos_EpetraExt_Headers.hpp"
#include "PyTrilinos_Domi_Headers.hpp"
#include "PyTrilinos_Tpetra_Headers.hpp"
#include "PyTrilinos_Isorropia_Headers.hpp"
#include "PyTrilinos_Pliris_Headers.hpp"
#include "PyTrilinos_AztecOO_Headers.hpp"
#include "PyTrilinos_Galeri_Headers.hpp"
#include "PyTrilinos_Amesos_Headers.hpp"
#include "PyTrilinos_IFPACK_Headers.hpp"
#include "PyTrilinos_Komplex_Headers.hpp"
#include "PyTrilinos_ML_Headers.hpp"
#include "PyTrilinos_Anasazi_Headers.hpp"
#include "PyTrilinos_NOX_Headers.hpp"
#include "PyTrilinos_NOX_Abstract_Headers.hpp"
#include "PyTrilinos_NOX_Solver_Headers.hpp"
#include "PyTrilinos_NOX_StatusTest_Headers.hpp"
#include "PyTrilinos_NOX_Epetra_Headers.hpp"
#include "PyTrilinos_LOCA_Headers.hpp"
#include "PyTrilinos_LOCA_Hopf_Headers.hpp"
#include "PyTrilinos_LOCA_Epetra_Headers.hpp"
%}


// Standard SWIG %include files
%include "stl.i"
%include "std_iostream.i"

// SWIG NumPy interface file
%include "numpy.i"

// Define the typedefs for SWIG processing
%inline
%{
  typedef Tpetra::Details::DefaultTypes::scalar_type DefaultScalarType;
  typedef Tpetra::Details::DefaultTypes::local_ordinal_type DefaultLOType;
  typedef Tpetra::Details::DefaultTypes::global_ordinal_type DefaultGOType;
%}

// Tell SWIG about the PyTrilinos configuration
%include "PyTrilinos_config.h"

// Tell SWIG the MPI version
#define MPI_VERSION 3

// Tell SWIG about the DLL export macros
%include "Teuchos_DLLExportMacro.h"
%include "Epetra_DLLExportMacro.h"
%include "Anasaziepetra_DLLExportMacro.h"

// Turn off warnings
# pragma SWIG nowarn=302
# pragma SWIG nowarn=314
# pragma SWIG nowarn=317
# pragma SWIG nowarn=325
# pragma SWIG nowarn=362
# pragma SWIG nowarn=389

// %ignore classes that will get %imported but whose base classes do not
// get %imported
%ignore MLAPI::MultiVector;

// Import the Trilinos header files
%import "Teuchos_LabeledObject.hpp"
%import "Teuchos_Describable.hpp"
%import "Epetra_Object.h"
%import "Epetra_CompObject.h"
%import "Epetra_SrcDistObject.h"
%import "Epetra_DistObject.h"
%import "Epetra_BlockMap.h"
%import "Epetra_Map.h"
%import "Epetra_BLAS.h"
%import "Epetra_MultiVector.h"
%import "Epetra_SerialDenseOperator.h"
%import "Epetra_Operator.h"
%import "Epetra_RowMatrix.h"
%import "Epetra_VbrMatrix.h"
%import "Isorropia_Operator.hpp"
%import "Isorropia_Partitioner.hpp"
%import "Isorropia_Redistributor.hpp"
%import "Isorropia_Orderer.hpp"
%import "Isorropia_LevelScheduler.hpp"
%import "Isorropia_EpetraOperator.hpp"
%import "Ifpack_Preconditioner.h"
%import "AnasaziTypes.hpp"
%import "AnasaziOutputManager.hpp"
%import "AnasaziSortManager.hpp"
%import "AnasaziEigenproblem.hpp"
%import "AnasaziOrthoManager.hpp"
%import "NOX_StatusTest_Generic.H"
%import "NOX_Epetra_Interface_Preconditioner.H"
%import "NOX_Epetra_Interface_Jacobian.H"
%import "NOX_Epetra_Interface_Required.H"
%import "NOX_Abstract_Group.H"
%import "NOX_Epetra_Group.H"
%import "LOCA_MultiContinuation_AbstractGroup.H"
%import "LOCA_TurningPoint_MooreSpence_AbstractGroup.H"
%import "LOCA_TurningPoint_MinimallyAugmented_AbstractGroup.H"
%import "LOCA_Homotopy_AbstractGroup.H"
%import "LOCA_Pitchfork_MooreSpence_AbstractGroup.H"
%import "LOCA_Pitchfork_MinimallyAugmented_AbstractGroup.H"
%import "LOCA_MultiContinuation_FiniteDifferenceGroup.H"
%import "LOCA_TurningPoint_MooreSpence_FiniteDifferenceGroup.H"
%import "LOCA_TurningPoint_MinimallyAugmented_FiniteDifferenceGroup.H"
%import "LOCA_TimeDependent_AbstractGroup.H"
%import "LOCA_Hopf_MooreSpence_AbstractGroup.H"
%import "LOCA_Hopf_MinimallyAugmented_AbstractGroup.H"
%import "LOCA_Hopf_MooreSpence_FiniteDifferenceGroup.H"
%import "LOCA_Hopf_MinimallyAugmented_FiniteDifferenceGroup.H"
%import "LOCA_PhaseTransition_AbstractGroup.H"
%import "LOCA_Abstract_Group.H"
%import "LOCA_Abstract_TransposeSolveGroup.H"
%import "LOCA_Epetra_Group.H"
%import "LOCA_Epetra_Interface_Required.H"
%import "LOCA_Hopf_MooreSpence_SolverStrategy.H"
%import "LOCA_MultiContinuation_ConstraintInterface.H"
%import "LOCA_MultiContinuation_ConstraintInterfaceMVDX.H"
%import "AnasaziBasicEigenproblem.hpp"
%import "AnasaziBasicOrthoManager.hpp"
%import "AnasaziBasicOutputManager.hpp"
%import "AnasaziBasicSort.hpp"
%import "AnasaziMatOrthoManager.hpp"
%import "AnasaziMultiVec.hpp"
%template(MultiVecDouble) Anasazi::MultiVec<double>;
%import "AnasaziOperator.hpp"
%template(OperatorDouble) Anasazi::Operator<double>;
%import "AnasaziSVQBOrthoManager.hpp"
%import "AnasaziStatusTest.hpp"
%import "AnasaziStatusTestCombo.hpp"
%import "AnasaziStatusTestMaxIters.hpp"
%import "AnasaziStatusTestOutput.hpp"
%import "AnasaziStatusTestResNorm.hpp"
%import "AnasaziEpetraAdapter.hpp"
%import "Domi_MDComm.hpp"
%import "Domi_MDMap.hpp"
%import "Domi_MDVector.hpp"
%import "EpetraExt_ModelEvaluator.h"
%import "Epetra_BasicRowMatrix.h"
%import "Epetra_Comm.h"
%import "Epetra_CrsGraph.h"
%import "Epetra_CrsMatrix.h"
%import "Epetra_Distributor.h"
%import "Epetra_Export.h"
%import "Epetra_FECrsGraph.h"
%import "Epetra_FECrsMatrix.h"
%import "Epetra_FEVbrMatrix.h"
%import "Epetra_FEVector.h"
%import "Epetra_Import.h"
%import "Epetra_IntSerialDenseMatrix.h"
%import "Epetra_IntSerialDenseVector.h"
%import "Epetra_IntVector.h"
%import "Epetra_InvOperator.h"
%import "Epetra_JadMatrix.h"
%import "Epetra_LAPACK.h"
%import "Epetra_LinearProblem.h"
%import "Epetra_LocalMap.h"
%import "Epetra_MapColoring.h"
#ifdef HAVE_MPI
%import "Epetra_MpiComm.h"
#endif
#ifdef HAVE_MPI
%import "Epetra_MpiDistributor.h"
#endif
%import "Epetra_OffsetIndex.h"
%import "Epetra_SerialComm.h"
%import "Epetra_SerialDenseMatrix.h"
%import "Epetra_SerialDenseSVD.h"
%import "Epetra_SerialDenseSolver.h"
%import "Epetra_SerialDenseVector.h"
%import "Epetra_SerialDistributor.h"
%import "Epetra_SerialSymDenseMatrix.h"
%import "Epetra_Time.h"
%import "Epetra_Vector.h"
%import "Ifpack_Amesos.h"
%import "Ifpack_IC.h"
%import "Ifpack_ICT.h"
%import "Ifpack_ILU.h"
%import "Ifpack_ILUT.h"
%import "Ifpack_PointRelaxation.h"
%import "Isorropia_Colorer.hpp"
%import "Isorropia_CostDescriber.hpp"
%import "Isorropia_EpetraColorer.hpp"
%import "Isorropia_EpetraCostDescriber.hpp"
%import "Isorropia_EpetraLevelScheduler.hpp"
%import "Isorropia_EpetraOrderer.hpp"
%import "Isorropia_EpetraPartitioner.hpp"
%import "Isorropia_EpetraRedistributor.hpp"
%import "LOCA_Abstract_Factory.H"
%import "LOCA_Abstract_Iterator.H"
%import "LOCA_AnasaziOperator_AbstractStrategy.H"
%import "LOCA_AnasaziOperator_Factory.H"
%import "LOCA_BorderedSolver_Factory.H"
%import "LOCA_BorderedSystem_AbstractGroup.H"
%import "LOCA_DerivUtils.H"
%import "LOCA_Eigensolver_Factory.H"
%import "LOCA_EigenvalueSort_Factory.H"
%import "LOCA_Epetra_Interface_MassMatrix.H"
%import "LOCA_Epetra_Interface_TimeDependent.H"
%import "LOCA_Epetra_Interface_TimeDependentMatrixFree.H"
%import "LOCA_ErrorCheck.H"
%import "LOCA_Extended_MultiAbstractGroup.H"
%import "LOCA_Factory.H"
%import "LOCA_GlobalData.H"
%import "LOCA_Homotopy_DeflatedGroup.H"
%import "LOCA_Homotopy_Group.H"
%import "LOCA_Hopf_MinimallyAugmented_Constraint.H"
%import "LOCA_Hopf_MinimallyAugmented_ExtendedGroup.H"
%import "LOCA_Hopf_MooreSpence_ExtendedGroup.H"
%import "LOCA_Hopf_MooreSpence_SalingerBordering.H"
%import "LOCA_Hopf_MooreSpence_SolverFactory.H"
%import "LOCA_MultiContinuation_Factory.H"
%import "LOCA_MultiPredictor_Factory.H"
%import "LOCA_Parameter_Library.H"
%import "LOCA_Pitchfork_MooreSpence_SolverFactory.H"
%import "LOCA_SaveEigenData_AbstractStrategy.H"
%import "LOCA_SaveEigenData_DefaultStrategy.H"
%import "LOCA_SaveEigenData_Factory.H"
%import "LOCA_StatusTest_Abstract.H"
%import "LOCA_StatusTest_Wrapper.H"
%import "LOCA_StepSize_Factory.H"
%import "LOCA_Stepper.H"
%import "LOCA_TurningPoint_MooreSpence_SolverFactory.H"
%import "MLAPI_MultiVector.h"
%import "MLAPI_EpetraBaseOperator.h"
%import "MLAPI_Operator_Box.h"
%import "ml_MultiLevelPreconditioner.h"
%import "NOX_Abstract_PrePostOperator.H"
%import "NOX_Epetra_FiniteDifference.H"
%import "NOX_Epetra_FiniteDifferenceColoring.H"
%import "NOX_Epetra_LinearSystem.H"
%import "NOX_Epetra_LinearSystem_AztecOO.H"
%import "NOX_Epetra_MatrixFree.H"
%import "NOX_Epetra_ModelEvaluatorInterface.H"
%import "NOX_Epetra_Scaling.H"
%import "NOX_Epetra_VectorSpace.H"
%import "NOX_Solver_Generic.H"
%import "NOX_Solver_InexactTrustRegionBased.H"
%import "NOX_Solver_LineSearchBased.H"
%import "NOX_Solver_TensorBased.H"
%import "NOX_Solver_TrustRegionBased.H"
%import "NOX_StatusTest_Combo.H"
%import "NOX_StatusTest_FiniteValue.H"
%import "NOX_StatusTest_MaxIters.H"
%import "NOX_StatusTest_NormF.H"
%import "NOX_StatusTest_NormUpdate.H"
%import "NOX_StatusTest_NormWRMS.H"
%import "NOX_StatusTest_Stagnation.H"
%import "PyTrilinos_LinearProblem.hpp"
%import "Teuchos_DefaultComm.hpp"
#ifdef HAVE_MPI
%import "Teuchos_DefaultMpiComm.hpp"
#endif
%import "Teuchos_ParameterList.hpp"
%import "Teuchos_ParameterListModifier.hpp"
%import "Teuchos_DefaultSerialComm.hpp"
%import "Teuchos_SerialDenseMatrix.hpp"
%import "Teuchos_Time.hpp"
%import "Tpetra_Details_Transfer.hpp"
%import "Tpetra_DistObject.hpp"
%import "Tpetra_Export_decl.hpp"
%import "Tpetra_Import_decl.hpp"
%import "TpetraCore_config.h"
%import "Tpetra_Map_decl.hpp"
%import "Tpetra_MultiVector.hpp"
%import "Tpetra_SrcDistObject.hpp"
%import "Tpetra_Vector.hpp"

%feature("docstring")
is_null
"is_null(obj) -> bool

Return true if obj is a python wrapper for a C++ object stored as a
Teuchos::RCP and the underlying pointer is NULL"

%feature("docstring")
is_valid_ptr
"is_valid_ptr(obj) -> bool

Return true if obj is a python wrapper for a C++ object stored as a
Teuchos::RCP and the underlying pointer is valid"

%feature("docstring")
has_ownership
"has_ownership(obj) -> bool

Return true if obj is a python wrapper for a C++ object stored as a
Teuchos::RCP that has ownership of the underlying pointer"

%feature("docstring")
strong_count
"strong_count(obj) -> int

If obj is a python wrapper for a C++ object stored as a Teuchos::RCP,
return the strong reference count"

%feature("docstring")
weak_count
"weak_count(obj) -> int

If obj is a python wrapper for a C++ object stored as a Teuchos::RCP,
return the weak reference count"

%feature("docstring")
total_count
"total_count(obj) -> int

If obj is a python wrapper for a C++ object stored as a Teuchos::RCP,
return the total reference count"

%inline
{

// Tpetra::Vector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::Vector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::Vector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::Vector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::Vector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::Vector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::Vector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::Vector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::Vector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::Vector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::Vector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::Vector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::Vector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::Vector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::Vector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::Vector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::Vector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::Vector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::Vector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::Vector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::Vector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::SrcDistObject
bool is_null(      Teuchos::RCP< Tpetra::SrcDistObject > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::SrcDistObject > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::SrcDistObject > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::SrcDistObject > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::SrcDistObject > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::SrcDistObject > & object){ return object.total_count()  ; }

// Tpetra::MultiVector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::MultiVector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::MultiVector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::MultiVector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::MultiVector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::MultiVector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::MultiVector<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::MultiVector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::MultiVector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::MultiVector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::MultiVector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::MultiVector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::MultiVector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::MultiVector<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::MultiVector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::MultiVector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::MultiVector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::MultiVector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::MultiVector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::MultiVector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::MultiVector<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::Map<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::Map<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::Map<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::Map<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::Map<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::Map<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::Map<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::Import<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::Import<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::Import<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::Import<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::Import<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::Import<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::Import<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::Export<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::Export<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::Export<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::Export<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::Export<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::Export<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::Export<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::DistObject<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::DistObject<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::DistObject<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::DistObject<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::DistObject<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::DistObject<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::DistObject<long long, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::DistObject<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::DistObject<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::DistObject<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::DistObject<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::DistObject<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::DistObject<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::DistObject<int, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::DistObject<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::DistObject<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::DistObject<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::DistObject<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::DistObject<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::DistObject<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::DistObject<double, PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Tpetra::Details::Transfer<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD >
bool is_null(      Teuchos::RCP< Tpetra::Details::Transfer<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Tpetra::Details::Transfer<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Tpetra::Details::Transfer<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Tpetra::Details::Transfer<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Tpetra::Details::Transfer<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Tpetra::Details::Transfer<PYTRILINOS_LOCAL_ORD, PYTRILINOS_GLOBAL_ORD > > & object){ return object.total_count()  ; }

// Teuchos::Time
bool is_null(      Teuchos::RCP< Teuchos::Time > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::Time > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::Time > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::Time > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::Time > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::Time > & object){ return object.total_count()  ; }

// Teuchos::SerialDenseMatrix<int, double>
bool is_null(      Teuchos::RCP< Teuchos::SerialDenseMatrix<int, double> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::SerialDenseMatrix<int, double> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::SerialDenseMatrix<int, double> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::SerialDenseMatrix<int, double> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::SerialDenseMatrix<int, double> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::SerialDenseMatrix<int, double> > & object){ return object.total_count()  ; }

// Teuchos::SerialComm<int>
bool is_null(      Teuchos::RCP< Teuchos::SerialComm<int> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::SerialComm<int> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::SerialComm<int> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::SerialComm<int> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::SerialComm<int> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::SerialComm<int> > & object){ return object.total_count()  ; }

// Teuchos::ParameterListModifier
bool is_null(      Teuchos::RCP< Teuchos::ParameterListModifier > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::ParameterListModifier > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::ParameterListModifier > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::ParameterListModifier > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::ParameterListModifier > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::ParameterListModifier > & object){ return object.total_count()  ; }

// Teuchos::ParameterList
bool is_null(      Teuchos::RCP< Teuchos::ParameterList > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::ParameterList > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::ParameterList > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::ParameterList > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::ParameterList > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::ParameterList > & object){ return object.total_count()  ; }

// Teuchos::MpiComm<int>
#ifdef HAVE_MPI
bool is_null(      Teuchos::RCP< Teuchos::MpiComm<int> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::MpiComm<int> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::MpiComm<int> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::MpiComm<int> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::MpiComm<int> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::MpiComm<int> > & object){ return object.total_count()  ; }
#endif

// Teuchos::Comm<int>
bool is_null(      Teuchos::RCP< Teuchos::Comm<int> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::Comm<int> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::Comm<int> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::Comm<int> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::Comm<int> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::Comm<int> > & object){ return object.total_count()  ; }

// PyTrilinos::LinearProblem
bool is_null(      Teuchos::RCP< PyTrilinos::LinearProblem > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< PyTrilinos::LinearProblem > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< PyTrilinos::LinearProblem > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< PyTrilinos::LinearProblem > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< PyTrilinos::LinearProblem > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< PyTrilinos::LinearProblem > & object){ return object.total_count()  ; }

// NOX::StatusTest::Stagnation
bool is_null(      Teuchos::RCP< NOX::StatusTest::Stagnation > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::Stagnation > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::Stagnation > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::Stagnation > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::Stagnation > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::Stagnation > & object){ return object.total_count()  ; }

// NOX::StatusTest::NormWRMS
bool is_null(      Teuchos::RCP< NOX::StatusTest::NormWRMS > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::NormWRMS > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::NormWRMS > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::NormWRMS > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::NormWRMS > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::NormWRMS > & object){ return object.total_count()  ; }

// NOX::StatusTest::NormUpdate
bool is_null(      Teuchos::RCP< NOX::StatusTest::NormUpdate > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::NormUpdate > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::NormUpdate > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::NormUpdate > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::NormUpdate > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::NormUpdate > & object){ return object.total_count()  ; }

// NOX::StatusTest::NormF
bool is_null(      Teuchos::RCP< NOX::StatusTest::NormF > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::NormF > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::NormF > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::NormF > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::NormF > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::NormF > & object){ return object.total_count()  ; }

// NOX::StatusTest::MaxIters
bool is_null(      Teuchos::RCP< NOX::StatusTest::MaxIters > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::MaxIters > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::MaxIters > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::MaxIters > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::MaxIters > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::MaxIters > & object){ return object.total_count()  ; }

// NOX::StatusTest::FiniteValue
bool is_null(      Teuchos::RCP< NOX::StatusTest::FiniteValue > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::FiniteValue > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::FiniteValue > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::FiniteValue > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::FiniteValue > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::FiniteValue > & object){ return object.total_count()  ; }

// NOX::StatusTest::Combo
bool is_null(      Teuchos::RCP< NOX::StatusTest::Combo > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::Combo > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::Combo > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::Combo > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::Combo > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::Combo > & object){ return object.total_count()  ; }

// NOX::Solver::TrustRegionBased
bool is_null(      Teuchos::RCP< NOX::Solver::TrustRegionBased > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Solver::TrustRegionBased > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Solver::TrustRegionBased > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Solver::TrustRegionBased > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Solver::TrustRegionBased > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Solver::TrustRegionBased > & object){ return object.total_count()  ; }

// NOX::Solver::TensorBased
bool is_null(      Teuchos::RCP< NOX::Solver::TensorBased > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Solver::TensorBased > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Solver::TensorBased > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Solver::TensorBased > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Solver::TensorBased > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Solver::TensorBased > & object){ return object.total_count()  ; }

// NOX::Solver::LineSearchBased
bool is_null(      Teuchos::RCP< NOX::Solver::LineSearchBased > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Solver::LineSearchBased > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Solver::LineSearchBased > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Solver::LineSearchBased > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Solver::LineSearchBased > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Solver::LineSearchBased > & object){ return object.total_count()  ; }

// NOX::Solver::InexactTrustRegionBased
bool is_null(      Teuchos::RCP< NOX::Solver::InexactTrustRegionBased > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Solver::InexactTrustRegionBased > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Solver::InexactTrustRegionBased > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Solver::InexactTrustRegionBased > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Solver::InexactTrustRegionBased > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Solver::InexactTrustRegionBased > & object){ return object.total_count()  ; }

// NOX::Solver::Generic
bool is_null(      Teuchos::RCP< NOX::Solver::Generic > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Solver::Generic > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Solver::Generic > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Solver::Generic > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Solver::Generic > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Solver::Generic > & object){ return object.total_count()  ; }

// NOX::Epetra::VectorSpace
bool is_null(      Teuchos::RCP< NOX::Epetra::VectorSpace > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::VectorSpace > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::VectorSpace > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::VectorSpace > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::VectorSpace > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::VectorSpace > & object){ return object.total_count()  ; }

// NOX::Epetra::Scaling
bool is_null(      Teuchos::RCP< NOX::Epetra::Scaling > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::Scaling > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::Scaling > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::Scaling > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::Scaling > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::Scaling > & object){ return object.total_count()  ; }

// NOX::Epetra::ModelEvaluatorInterface
bool is_null(      Teuchos::RCP< NOX::Epetra::ModelEvaluatorInterface > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::ModelEvaluatorInterface > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::ModelEvaluatorInterface > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::ModelEvaluatorInterface > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::ModelEvaluatorInterface > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::ModelEvaluatorInterface > & object){ return object.total_count()  ; }

// NOX::Epetra::MatrixFree
bool is_null(      Teuchos::RCP< NOX::Epetra::MatrixFree > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::MatrixFree > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::MatrixFree > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::MatrixFree > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::MatrixFree > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::MatrixFree > & object){ return object.total_count()  ; }

// NOX::Epetra::LinearSystemAztecOO
bool is_null(      Teuchos::RCP< NOX::Epetra::LinearSystemAztecOO > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::LinearSystemAztecOO > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::LinearSystemAztecOO > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::LinearSystemAztecOO > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::LinearSystemAztecOO > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::LinearSystemAztecOO > & object){ return object.total_count()  ; }

// NOX::Epetra::LinearSystem
bool is_null(      Teuchos::RCP< NOX::Epetra::LinearSystem > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::LinearSystem > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::LinearSystem > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::LinearSystem > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::LinearSystem > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::LinearSystem > & object){ return object.total_count()  ; }

// NOX::Epetra::FiniteDifferenceColoring
bool is_null(      Teuchos::RCP< NOX::Epetra::FiniteDifferenceColoring > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::FiniteDifferenceColoring > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::FiniteDifferenceColoring > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::FiniteDifferenceColoring > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::FiniteDifferenceColoring > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::FiniteDifferenceColoring > & object){ return object.total_count()  ; }

// NOX::Epetra::FiniteDifference
bool is_null(      Teuchos::RCP< NOX::Epetra::FiniteDifference > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::FiniteDifference > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::FiniteDifference > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::FiniteDifference > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::FiniteDifference > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::FiniteDifference > & object){ return object.total_count()  ; }

// NOX::Abstract::PrePostOperator
bool is_null(      Teuchos::RCP< NOX::Abstract::PrePostOperator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Abstract::PrePostOperator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Abstract::PrePostOperator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Abstract::PrePostOperator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Abstract::PrePostOperator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Abstract::PrePostOperator > & object){ return object.total_count()  ; }

// ML_Epetra::MultiLevelPreconditioner
bool is_null(      Teuchos::RCP< ML_Epetra::MultiLevelPreconditioner > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< ML_Epetra::MultiLevelPreconditioner > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< ML_Epetra::MultiLevelPreconditioner > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< ML_Epetra::MultiLevelPreconditioner > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< ML_Epetra::MultiLevelPreconditioner > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< ML_Epetra::MultiLevelPreconditioner > & object){ return object.total_count()  ; }

// MLAPI::ML_Operator_Box
bool is_null(      Teuchos::RCP< MLAPI::ML_Operator_Box > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< MLAPI::ML_Operator_Box > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< MLAPI::ML_Operator_Box > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< MLAPI::ML_Operator_Box > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< MLAPI::ML_Operator_Box > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< MLAPI::ML_Operator_Box > & object){ return object.total_count()  ; }

// MLAPI::EpetraBaseOperator
bool is_null(      Teuchos::RCP< MLAPI::EpetraBaseOperator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< MLAPI::EpetraBaseOperator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< MLAPI::EpetraBaseOperator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< MLAPI::EpetraBaseOperator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< MLAPI::EpetraBaseOperator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< MLAPI::EpetraBaseOperator > & object){ return object.total_count()  ; }

// MLAPI::DoubleVector
bool is_null(      Teuchos::RCP< MLAPI::DoubleVector > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< MLAPI::DoubleVector > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< MLAPI::DoubleVector > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< MLAPI::DoubleVector > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< MLAPI::DoubleVector > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< MLAPI::DoubleVector > & object){ return object.total_count()  ; }

// LOCA::TurningPoint::MooreSpence::SolverFactory
bool is_null(      Teuchos::RCP< LOCA::TurningPoint::MooreSpence::SolverFactory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::TurningPoint::MooreSpence::SolverFactory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::TurningPoint::MooreSpence::SolverFactory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::TurningPoint::MooreSpence::SolverFactory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::TurningPoint::MooreSpence::SolverFactory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::TurningPoint::MooreSpence::SolverFactory > & object){ return object.total_count()  ; }

// LOCA::Stepper
bool is_null(      Teuchos::RCP< LOCA::Stepper > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Stepper > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Stepper > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Stepper > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Stepper > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Stepper > & object){ return object.total_count()  ; }

// LOCA::StepSize::Factory
bool is_null(      Teuchos::RCP< LOCA::StepSize::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::StepSize::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::StepSize::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::StepSize::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::StepSize::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::StepSize::Factory > & object){ return object.total_count()  ; }

// LOCA::StatusTest::Wrapper
bool is_null(      Teuchos::RCP< LOCA::StatusTest::Wrapper > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::StatusTest::Wrapper > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::StatusTest::Wrapper > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::StatusTest::Wrapper > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::StatusTest::Wrapper > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::StatusTest::Wrapper > & object){ return object.total_count()  ; }

// LOCA::StatusTest::Abstract
bool is_null(      Teuchos::RCP< LOCA::StatusTest::Abstract > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::StatusTest::Abstract > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::StatusTest::Abstract > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::StatusTest::Abstract > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::StatusTest::Abstract > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::StatusTest::Abstract > & object){ return object.total_count()  ; }

// LOCA::SaveEigenData::Factory
bool is_null(      Teuchos::RCP< LOCA::SaveEigenData::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::SaveEigenData::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::SaveEigenData::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::SaveEigenData::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::SaveEigenData::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::SaveEigenData::Factory > & object){ return object.total_count()  ; }

// LOCA::SaveEigenData::DefaultStrategy
bool is_null(      Teuchos::RCP< LOCA::SaveEigenData::DefaultStrategy > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::SaveEigenData::DefaultStrategy > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::SaveEigenData::DefaultStrategy > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::SaveEigenData::DefaultStrategy > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::SaveEigenData::DefaultStrategy > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::SaveEigenData::DefaultStrategy > & object){ return object.total_count()  ; }

// LOCA::SaveEigenData::AbstractStrategy
bool is_null(      Teuchos::RCP< LOCA::SaveEigenData::AbstractStrategy > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::SaveEigenData::AbstractStrategy > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::SaveEigenData::AbstractStrategy > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::SaveEigenData::AbstractStrategy > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::SaveEigenData::AbstractStrategy > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::SaveEigenData::AbstractStrategy > & object){ return object.total_count()  ; }

// LOCA::Pitchfork::MooreSpence::SolverFactory
bool is_null(      Teuchos::RCP< LOCA::Pitchfork::MooreSpence::SolverFactory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Pitchfork::MooreSpence::SolverFactory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Pitchfork::MooreSpence::SolverFactory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Pitchfork::MooreSpence::SolverFactory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Pitchfork::MooreSpence::SolverFactory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Pitchfork::MooreSpence::SolverFactory > & object){ return object.total_count()  ; }

// LOCA::Parameter::Library
bool is_null(      Teuchos::RCP< LOCA::Parameter::Library > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Parameter::Library > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Parameter::Library > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Parameter::Library > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Parameter::Library > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Parameter::Library > & object){ return object.total_count()  ; }

// LOCA::MultiPredictor::Factory
bool is_null(      Teuchos::RCP< LOCA::MultiPredictor::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::MultiPredictor::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::MultiPredictor::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::MultiPredictor::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::MultiPredictor::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::MultiPredictor::Factory > & object){ return object.total_count()  ; }

// LOCA::MultiContinuation::Factory
bool is_null(      Teuchos::RCP< LOCA::MultiContinuation::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::MultiContinuation::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::MultiContinuation::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::MultiContinuation::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::MultiContinuation::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::MultiContinuation::Factory > & object){ return object.total_count()  ; }

// LOCA::Hopf::MooreSpence::SolverFactory
bool is_null(      Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverFactory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverFactory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverFactory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverFactory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverFactory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverFactory > & object){ return object.total_count()  ; }

// LOCA::Hopf::MooreSpence::SalingerBordering
bool is_null(      Teuchos::RCP< LOCA::Hopf::MooreSpence::SalingerBordering > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MooreSpence::SalingerBordering > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MooreSpence::SalingerBordering > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MooreSpence::SalingerBordering > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MooreSpence::SalingerBordering > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MooreSpence::SalingerBordering > & object){ return object.total_count()  ; }

// LOCA::Hopf::MooreSpence::ExtendedGroup
bool is_null(      Teuchos::RCP< LOCA::Hopf::MooreSpence::ExtendedGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MooreSpence::ExtendedGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MooreSpence::ExtendedGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MooreSpence::ExtendedGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MooreSpence::ExtendedGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MooreSpence::ExtendedGroup > & object){ return object.total_count()  ; }

// LOCA::Hopf::MinimallyAugmented::ExtendedGroup
bool is_null(      Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::ExtendedGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::ExtendedGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::ExtendedGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::ExtendedGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::ExtendedGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::ExtendedGroup > & object){ return object.total_count()  ; }

// LOCA::Hopf::MinimallyAugmented::Constraint
bool is_null(      Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::Constraint > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::Constraint > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::Constraint > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::Constraint > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::Constraint > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::Constraint > & object){ return object.total_count()  ; }

// LOCA::Homotopy::Group
bool is_null(      Teuchos::RCP< LOCA::Homotopy::Group > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Homotopy::Group > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Homotopy::Group > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Homotopy::Group > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Homotopy::Group > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Homotopy::Group > & object){ return object.total_count()  ; }

// LOCA::Homotopy::DeflatedGroup
bool is_null(      Teuchos::RCP< LOCA::Homotopy::DeflatedGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Homotopy::DeflatedGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Homotopy::DeflatedGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Homotopy::DeflatedGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Homotopy::DeflatedGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Homotopy::DeflatedGroup > & object){ return object.total_count()  ; }

// LOCA::GlobalData
bool is_null(      Teuchos::RCP< LOCA::GlobalData > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::GlobalData > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::GlobalData > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::GlobalData > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::GlobalData > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::GlobalData > & object){ return object.total_count()  ; }

// LOCA::Factory
bool is_null(      Teuchos::RCP< LOCA::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Factory > & object){ return object.total_count()  ; }

// LOCA::Extended::MultiAbstractGroup
bool is_null(      Teuchos::RCP< LOCA::Extended::MultiAbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Extended::MultiAbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Extended::MultiAbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Extended::MultiAbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Extended::MultiAbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Extended::MultiAbstractGroup > & object){ return object.total_count()  ; }

// LOCA::ErrorCheck
bool is_null(      Teuchos::RCP< LOCA::ErrorCheck > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::ErrorCheck > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::ErrorCheck > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::ErrorCheck > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::ErrorCheck > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::ErrorCheck > & object){ return object.total_count()  ; }

// LOCA::Epetra::Interface::TimeDependentMatrixFree
bool is_null(      Teuchos::RCP< LOCA::Epetra::Interface::TimeDependentMatrixFree > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Epetra::Interface::TimeDependentMatrixFree > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Epetra::Interface::TimeDependentMatrixFree > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Epetra::Interface::TimeDependentMatrixFree > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Epetra::Interface::TimeDependentMatrixFree > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Epetra::Interface::TimeDependentMatrixFree > & object){ return object.total_count()  ; }

// LOCA::Epetra::Interface::TimeDependent
bool is_null(      Teuchos::RCP< LOCA::Epetra::Interface::TimeDependent > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Epetra::Interface::TimeDependent > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Epetra::Interface::TimeDependent > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Epetra::Interface::TimeDependent > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Epetra::Interface::TimeDependent > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Epetra::Interface::TimeDependent > & object){ return object.total_count()  ; }

// LOCA::Epetra::Interface::MassMatrix
bool is_null(      Teuchos::RCP< LOCA::Epetra::Interface::MassMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Epetra::Interface::MassMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Epetra::Interface::MassMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Epetra::Interface::MassMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Epetra::Interface::MassMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Epetra::Interface::MassMatrix > & object){ return object.total_count()  ; }

// LOCA::EigenvalueSort::Factory
bool is_null(      Teuchos::RCP< LOCA::EigenvalueSort::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::EigenvalueSort::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::EigenvalueSort::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::EigenvalueSort::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::EigenvalueSort::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::EigenvalueSort::Factory > & object){ return object.total_count()  ; }

// LOCA::Eigensolver::Factory
bool is_null(      Teuchos::RCP< LOCA::Eigensolver::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Eigensolver::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Eigensolver::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Eigensolver::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Eigensolver::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Eigensolver::Factory > & object){ return object.total_count()  ; }

// LOCA::DerivUtils
bool is_null(      Teuchos::RCP< LOCA::DerivUtils > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::DerivUtils > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::DerivUtils > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::DerivUtils > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::DerivUtils > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::DerivUtils > & object){ return object.total_count()  ; }

// LOCA::BorderedSystem::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::BorderedSystem::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::BorderedSystem::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::BorderedSystem::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::BorderedSystem::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::BorderedSystem::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::BorderedSystem::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::BorderedSolver::Factory
bool is_null(      Teuchos::RCP< LOCA::BorderedSolver::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::BorderedSolver::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::BorderedSolver::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::BorderedSolver::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::BorderedSolver::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::BorderedSolver::Factory > & object){ return object.total_count()  ; }

// LOCA::AnasaziOperator::Factory
bool is_null(      Teuchos::RCP< LOCA::AnasaziOperator::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::AnasaziOperator::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::AnasaziOperator::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::AnasaziOperator::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::AnasaziOperator::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::AnasaziOperator::Factory > & object){ return object.total_count()  ; }

// LOCA::AnasaziOperator::AbstractStrategy
bool is_null(      Teuchos::RCP< LOCA::AnasaziOperator::AbstractStrategy > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::AnasaziOperator::AbstractStrategy > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::AnasaziOperator::AbstractStrategy > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::AnasaziOperator::AbstractStrategy > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::AnasaziOperator::AbstractStrategy > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::AnasaziOperator::AbstractStrategy > & object){ return object.total_count()  ; }

// LOCA::Abstract::Iterator
bool is_null(      Teuchos::RCP< LOCA::Abstract::Iterator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Abstract::Iterator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Abstract::Iterator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Abstract::Iterator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Abstract::Iterator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Abstract::Iterator > & object){ return object.total_count()  ; }

// LOCA::Abstract::Factory
bool is_null(      Teuchos::RCP< LOCA::Abstract::Factory > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Abstract::Factory > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Abstract::Factory > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Abstract::Factory > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Abstract::Factory > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Abstract::Factory > & object){ return object.total_count()  ; }

// Isorropia::Epetra::Redistributor
bool is_null(      Teuchos::RCP< Isorropia::Epetra::Redistributor > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Epetra::Redistributor > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Epetra::Redistributor > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Epetra::Redistributor > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Epetra::Redistributor > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Epetra::Redistributor > & object){ return object.total_count()  ; }

// Isorropia::Epetra::Partitioner
bool is_null(      Teuchos::RCP< Isorropia::Epetra::Partitioner > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Epetra::Partitioner > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Epetra::Partitioner > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Epetra::Partitioner > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Epetra::Partitioner > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Epetra::Partitioner > & object){ return object.total_count()  ; }

// Isorropia::Epetra::Orderer
bool is_null(      Teuchos::RCP< Isorropia::Epetra::Orderer > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Epetra::Orderer > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Epetra::Orderer > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Epetra::Orderer > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Epetra::Orderer > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Epetra::Orderer > & object){ return object.total_count()  ; }

// Isorropia::Epetra::LevelScheduler
bool is_null(      Teuchos::RCP< Isorropia::Epetra::LevelScheduler > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Epetra::LevelScheduler > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Epetra::LevelScheduler > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Epetra::LevelScheduler > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Epetra::LevelScheduler > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Epetra::LevelScheduler > & object){ return object.total_count()  ; }

// Isorropia::Epetra::CostDescriber
bool is_null(      Teuchos::RCP< Isorropia::Epetra::CostDescriber > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Epetra::CostDescriber > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Epetra::CostDescriber > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Epetra::CostDescriber > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Epetra::CostDescriber > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Epetra::CostDescriber > & object){ return object.total_count()  ; }

// Isorropia::Epetra::Colorer
bool is_null(      Teuchos::RCP< Isorropia::Epetra::Colorer > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Epetra::Colorer > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Epetra::Colorer > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Epetra::Colorer > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Epetra::Colorer > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Epetra::Colorer > & object){ return object.total_count()  ; }

// Isorropia::CostDescriber
bool is_null(      Teuchos::RCP< Isorropia::CostDescriber > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::CostDescriber > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::CostDescriber > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::CostDescriber > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::CostDescriber > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::CostDescriber > & object){ return object.total_count()  ; }

// Isorropia::Colorer
bool is_null(      Teuchos::RCP< Isorropia::Colorer > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Colorer > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Colorer > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Colorer > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Colorer > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Colorer > & object){ return object.total_count()  ; }

// Ifpack_PointRelaxation
bool is_null(      Teuchos::RCP< Ifpack_PointRelaxation > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Ifpack_PointRelaxation > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Ifpack_PointRelaxation > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Ifpack_PointRelaxation > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Ifpack_PointRelaxation > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Ifpack_PointRelaxation > & object){ return object.total_count()  ; }

// Ifpack_ILUT
bool is_null(      Teuchos::RCP< Ifpack_ILUT > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Ifpack_ILUT > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Ifpack_ILUT > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Ifpack_ILUT > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Ifpack_ILUT > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Ifpack_ILUT > & object){ return object.total_count()  ; }

// Ifpack_ILU
bool is_null(      Teuchos::RCP< Ifpack_ILU > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Ifpack_ILU > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Ifpack_ILU > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Ifpack_ILU > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Ifpack_ILU > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Ifpack_ILU > & object){ return object.total_count()  ; }

// Ifpack_ICT
bool is_null(      Teuchos::RCP< Ifpack_ICT > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Ifpack_ICT > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Ifpack_ICT > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Ifpack_ICT > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Ifpack_ICT > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Ifpack_ICT > & object){ return object.total_count()  ; }

// Ifpack_IC
bool is_null(      Teuchos::RCP< Ifpack_IC > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Ifpack_IC > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Ifpack_IC > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Ifpack_IC > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Ifpack_IC > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Ifpack_IC > & object){ return object.total_count()  ; }

// Ifpack_Amesos
bool is_null(      Teuchos::RCP< Ifpack_Amesos > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Ifpack_Amesos > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Ifpack_Amesos > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Ifpack_Amesos > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Ifpack_Amesos > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Ifpack_Amesos > & object){ return object.total_count()  ; }

// Epetra_Vector
bool is_null(      Teuchos::RCP< Epetra_Vector > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Vector > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Vector > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Vector > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Vector > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Vector > & object){ return object.total_count()  ; }

// Epetra_Time
bool is_null(      Teuchos::RCP< Epetra_Time > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Time > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Time > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Time > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Time > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Time > & object){ return object.total_count()  ; }

// Epetra_SerialSymDenseMatrix
bool is_null(      Teuchos::RCP< Epetra_SerialSymDenseMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialSymDenseMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialSymDenseMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialSymDenseMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialSymDenseMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialSymDenseMatrix > & object){ return object.total_count()  ; }

// Epetra_SerialDistributor
bool is_null(      Teuchos::RCP< Epetra_SerialDistributor > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialDistributor > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialDistributor > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialDistributor > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialDistributor > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialDistributor > & object){ return object.total_count()  ; }

// Epetra_SerialDenseVector
bool is_null(      Teuchos::RCP< Epetra_SerialDenseVector > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialDenseVector > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialDenseVector > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialDenseVector > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialDenseVector > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialDenseVector > & object){ return object.total_count()  ; }

// Epetra_SerialDenseSolver
bool is_null(      Teuchos::RCP< Epetra_SerialDenseSolver > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialDenseSolver > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialDenseSolver > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialDenseSolver > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialDenseSolver > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialDenseSolver > & object){ return object.total_count()  ; }

// Epetra_SerialDenseSVD
bool is_null(      Teuchos::RCP< Epetra_SerialDenseSVD > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialDenseSVD > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialDenseSVD > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialDenseSVD > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialDenseSVD > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialDenseSVD > & object){ return object.total_count()  ; }

// Epetra_SerialDenseMatrix
bool is_null(      Teuchos::RCP< Epetra_SerialDenseMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialDenseMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialDenseMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialDenseMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialDenseMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialDenseMatrix > & object){ return object.total_count()  ; }

// Epetra_SerialComm
bool is_null(      Teuchos::RCP< Epetra_SerialComm > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialComm > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialComm > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialComm > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialComm > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialComm > & object){ return object.total_count()  ; }

// Epetra_OffsetIndex
bool is_null(      Teuchos::RCP< Epetra_OffsetIndex > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_OffsetIndex > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_OffsetIndex > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_OffsetIndex > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_OffsetIndex > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_OffsetIndex > & object){ return object.total_count()  ; }

// Epetra_MpiDistributor
#ifdef HAVE_MPI
bool is_null(      Teuchos::RCP< Epetra_MpiDistributor > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_MpiDistributor > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_MpiDistributor > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_MpiDistributor > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_MpiDistributor > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_MpiDistributor > & object){ return object.total_count()  ; }
#endif

// Epetra_MpiComm
#ifdef HAVE_MPI
bool is_null(      Teuchos::RCP< Epetra_MpiComm > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_MpiComm > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_MpiComm > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_MpiComm > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_MpiComm > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_MpiComm > & object){ return object.total_count()  ; }
#endif

// Epetra_MapColoring
bool is_null(      Teuchos::RCP< Epetra_MapColoring > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_MapColoring > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_MapColoring > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_MapColoring > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_MapColoring > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_MapColoring > & object){ return object.total_count()  ; }

// Epetra_LocalMap
bool is_null(      Teuchos::RCP< Epetra_LocalMap > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_LocalMap > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_LocalMap > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_LocalMap > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_LocalMap > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_LocalMap > & object){ return object.total_count()  ; }

// Epetra_LinearProblem
bool is_null(      Teuchos::RCP< Epetra_LinearProblem > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_LinearProblem > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_LinearProblem > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_LinearProblem > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_LinearProblem > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_LinearProblem > & object){ return object.total_count()  ; }

// Epetra_LAPACK
bool is_null(      Teuchos::RCP< Epetra_LAPACK > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_LAPACK > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_LAPACK > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_LAPACK > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_LAPACK > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_LAPACK > & object){ return object.total_count()  ; }

// Epetra_JadMatrix
bool is_null(      Teuchos::RCP< Epetra_JadMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_JadMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_JadMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_JadMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_JadMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_JadMatrix > & object){ return object.total_count()  ; }

// Epetra_InvOperator
bool is_null(      Teuchos::RCP< Epetra_InvOperator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_InvOperator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_InvOperator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_InvOperator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_InvOperator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_InvOperator > & object){ return object.total_count()  ; }

// Epetra_IntVector
bool is_null(      Teuchos::RCP< Epetra_IntVector > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_IntVector > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_IntVector > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_IntVector > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_IntVector > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_IntVector > & object){ return object.total_count()  ; }

// Epetra_IntSerialDenseVector
bool is_null(      Teuchos::RCP< Epetra_IntSerialDenseVector > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_IntSerialDenseVector > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_IntSerialDenseVector > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_IntSerialDenseVector > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_IntSerialDenseVector > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_IntSerialDenseVector > & object){ return object.total_count()  ; }

// Epetra_IntSerialDenseMatrix
bool is_null(      Teuchos::RCP< Epetra_IntSerialDenseMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_IntSerialDenseMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_IntSerialDenseMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_IntSerialDenseMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_IntSerialDenseMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_IntSerialDenseMatrix > & object){ return object.total_count()  ; }

// Epetra_Import
bool is_null(      Teuchos::RCP< Epetra_Import > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Import > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Import > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Import > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Import > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Import > & object){ return object.total_count()  ; }

// Epetra_FEVector
bool is_null(      Teuchos::RCP< Epetra_FEVector > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_FEVector > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_FEVector > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_FEVector > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_FEVector > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_FEVector > & object){ return object.total_count()  ; }

// Epetra_FEVbrMatrix
bool is_null(      Teuchos::RCP< Epetra_FEVbrMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_FEVbrMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_FEVbrMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_FEVbrMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_FEVbrMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_FEVbrMatrix > & object){ return object.total_count()  ; }

// Epetra_FECrsMatrix
bool is_null(      Teuchos::RCP< Epetra_FECrsMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_FECrsMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_FECrsMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_FECrsMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_FECrsMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_FECrsMatrix > & object){ return object.total_count()  ; }

// Epetra_FECrsGraph
bool is_null(      Teuchos::RCP< Epetra_FECrsGraph > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_FECrsGraph > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_FECrsGraph > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_FECrsGraph > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_FECrsGraph > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_FECrsGraph > & object){ return object.total_count()  ; }

// Epetra_Export
bool is_null(      Teuchos::RCP< Epetra_Export > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Export > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Export > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Export > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Export > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Export > & object){ return object.total_count()  ; }

// Epetra_Distributor
bool is_null(      Teuchos::RCP< Epetra_Distributor > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Distributor > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Distributor > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Distributor > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Distributor > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Distributor > & object){ return object.total_count()  ; }

// Epetra_CrsMatrix
bool is_null(      Teuchos::RCP< Epetra_CrsMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_CrsMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_CrsMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_CrsMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_CrsMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_CrsMatrix > & object){ return object.total_count()  ; }

// Epetra_CrsGraph
bool is_null(      Teuchos::RCP< Epetra_CrsGraph > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_CrsGraph > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_CrsGraph > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_CrsGraph > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_CrsGraph > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_CrsGraph > & object){ return object.total_count()  ; }

// Epetra_Comm
bool is_null(      Teuchos::RCP< Epetra_Comm > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Comm > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Comm > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Comm > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Comm > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Comm > & object){ return object.total_count()  ; }

// Epetra_BasicRowMatrix
bool is_null(      Teuchos::RCP< Epetra_BasicRowMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_BasicRowMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_BasicRowMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_BasicRowMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_BasicRowMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_BasicRowMatrix > & object){ return object.total_count()  ; }

// EpetraExt::ModelEvaluator
bool is_null(      Teuchos::RCP< EpetraExt::ModelEvaluator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< EpetraExt::ModelEvaluator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< EpetraExt::ModelEvaluator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< EpetraExt::ModelEvaluator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< EpetraExt::ModelEvaluator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< EpetraExt::ModelEvaluator > & object){ return object.total_count()  ; }

// Domi::MDVector<long long>
bool is_null(      Teuchos::RCP< Domi::MDVector<long long> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Domi::MDVector<long long> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Domi::MDVector<long long> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Domi::MDVector<long long> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Domi::MDVector<long long> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Domi::MDVector<long long> > & object){ return object.total_count()  ; }

// Domi::MDVector<int      >
bool is_null(      Teuchos::RCP< Domi::MDVector<int      > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Domi::MDVector<int      > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Domi::MDVector<int      > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Domi::MDVector<int      > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Domi::MDVector<int      > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Domi::MDVector<int      > > & object){ return object.total_count()  ; }

// Domi::MDVector<float    >
bool is_null(      Teuchos::RCP< Domi::MDVector<float    > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Domi::MDVector<float    > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Domi::MDVector<float    > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Domi::MDVector<float    > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Domi::MDVector<float    > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Domi::MDVector<float    > > & object){ return object.total_count()  ; }

// Domi::MDVector<double   >
bool is_null(      Teuchos::RCP< Domi::MDVector<double   > > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Domi::MDVector<double   > > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Domi::MDVector<double   > > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Domi::MDVector<double   > > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Domi::MDVector<double   > > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Domi::MDVector<double   > > & object){ return object.total_count()  ; }

// Domi::MDMap
bool is_null(      Teuchos::RCP< Domi::MDMap > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Domi::MDMap > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Domi::MDMap > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Domi::MDMap > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Domi::MDMap > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Domi::MDMap > & object){ return object.total_count()  ; }

// Domi::MDComm
bool is_null(      Teuchos::RCP< Domi::MDComm > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Domi::MDComm > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Domi::MDComm > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Domi::MDComm > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Domi::MDComm > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Domi::MDComm > & object){ return object.total_count()  ; }

// Anasazi::StatusTestResNorm<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::StatusTestResNorm<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::StatusTestResNorm<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::StatusTestResNorm<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::StatusTestResNorm<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::StatusTestResNorm<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::StatusTestResNorm<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::StatusTestOutput<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::StatusTestOutput<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::StatusTestOutput<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::StatusTestOutput<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::StatusTestOutput<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::StatusTestOutput<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::StatusTestOutput<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::StatusTestMaxIters<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::StatusTestMaxIters<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::StatusTestMaxIters<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::StatusTestMaxIters<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::StatusTestMaxIters<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::StatusTestMaxIters<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::StatusTestMaxIters<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::StatusTestCombo<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::StatusTestCombo<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::StatusTestCombo<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::StatusTestCombo<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::StatusTestCombo<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::StatusTestCombo<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::StatusTestCombo<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::StatusTest<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::StatusTest<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::StatusTest<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::StatusTest<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::StatusTest<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::StatusTest<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::StatusTest<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::SVQBOrthoManager<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::SVQBOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::SVQBOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::SVQBOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::SVQBOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::SVQBOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::SVQBOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::Operator<double>
bool is_null(      Teuchos::RCP< Anasazi::Operator<double> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::Operator<double> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::Operator<double> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::Operator<double> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::Operator<double> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::Operator<double> > & object){ return object.total_count()  ; }

// Anasazi::MultiVec<double>
bool is_null(      Teuchos::RCP< Anasazi::MultiVec<double> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::MultiVec<double> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::MultiVec<double> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::MultiVec<double> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::MultiVec<double> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::MultiVec<double> > & object){ return object.total_count()  ; }

// Anasazi::MatOrthoManager<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::MatOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::MatOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::MatOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::MatOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::MatOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::MatOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::EpetraWSymMVOp
bool is_null(      Teuchos::RCP< Anasazi::EpetraWSymMVOp > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraWSymMVOp > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraWSymMVOp > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraWSymMVOp > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraWSymMVOp > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraWSymMVOp > & object){ return object.total_count()  ; }

// Anasazi::EpetraW2SymMVOp
bool is_null(      Teuchos::RCP< Anasazi::EpetraW2SymMVOp > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraW2SymMVOp > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraW2SymMVOp > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraW2SymMVOp > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraW2SymMVOp > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraW2SymMVOp > & object){ return object.total_count()  ; }

// Anasazi::EpetraSymOp
bool is_null(      Teuchos::RCP< Anasazi::EpetraSymOp > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraSymOp > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraSymOp > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraSymOp > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraSymOp > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraSymOp > & object){ return object.total_count()  ; }

// Anasazi::EpetraSymMVOp
bool is_null(      Teuchos::RCP< Anasazi::EpetraSymMVOp > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraSymMVOp > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraSymMVOp > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraSymMVOp > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraSymMVOp > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraSymMVOp > & object){ return object.total_count()  ; }

// Anasazi::EpetraOp
bool is_null(      Teuchos::RCP< Anasazi::EpetraOp > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraOp > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraOp > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraOp > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraOp > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraOp > & object){ return object.total_count()  ; }

// Anasazi::EpetraMultiVecAccessor
bool is_null(      Teuchos::RCP< Anasazi::EpetraMultiVecAccessor > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraMultiVecAccessor > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraMultiVecAccessor > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraMultiVecAccessor > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraMultiVecAccessor > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraMultiVecAccessor > & object){ return object.total_count()  ; }

// Anasazi::EpetraMultiVec
bool is_null(      Teuchos::RCP< Anasazi::EpetraMultiVec > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraMultiVec > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraMultiVec > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraMultiVec > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraMultiVec > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraMultiVec > & object){ return object.total_count()  ; }

// Anasazi::EpetraGenOp
bool is_null(      Teuchos::RCP< Anasazi::EpetraGenOp > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::EpetraGenOp > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::EpetraGenOp > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::EpetraGenOp > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::EpetraGenOp > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::EpetraGenOp > & object){ return object.total_count()  ; }

// Anasazi::BasicSort<double>
bool is_null(      Teuchos::RCP< Anasazi::BasicSort<double> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::BasicSort<double> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::BasicSort<double> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::BasicSort<double> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::BasicSort<double> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::BasicSort<double> > & object){ return object.total_count()  ; }

// Anasazi::BasicOutputManager<double>
bool is_null(      Teuchos::RCP< Anasazi::BasicOutputManager<double> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::BasicOutputManager<double> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::BasicOutputManager<double> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::BasicOutputManager<double> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::BasicOutputManager<double> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::BasicOutputManager<double> > & object){ return object.total_count()  ; }

// Anasazi::BasicOrthoManager<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::BasicOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::BasicOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::BasicOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::BasicOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::BasicOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::BasicOrthoManager<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::BasicEigenproblem<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::BasicEigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::BasicEigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::BasicEigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::BasicEigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::BasicEigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::BasicEigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// LOCA::MultiContinuation::ConstraintInterfaceMVDX
bool is_null(      Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterfaceMVDX > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterfaceMVDX > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterfaceMVDX > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterfaceMVDX > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterfaceMVDX > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterfaceMVDX > & object){ return object.total_count()  ; }

// LOCA::MultiContinuation::ConstraintInterface
bool is_null(      Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterface > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterface > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterface > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterface > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterface > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::MultiContinuation::ConstraintInterface > & object){ return object.total_count()  ; }

// LOCA::Hopf::MooreSpence::SolverStrategy
bool is_null(      Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverStrategy > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverStrategy > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverStrategy > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverStrategy > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverStrategy > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MooreSpence::SolverStrategy > & object){ return object.total_count()  ; }

// LOCA::Epetra::Interface::Required
bool is_null(      Teuchos::RCP< LOCA::Epetra::Interface::Required > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Epetra::Interface::Required > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Epetra::Interface::Required > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Epetra::Interface::Required > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Epetra::Interface::Required > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Epetra::Interface::Required > & object){ return object.total_count()  ; }

// LOCA::Epetra::Group
bool is_null(      Teuchos::RCP< LOCA::Epetra::Group > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Epetra::Group > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Epetra::Group > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Epetra::Group > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Epetra::Group > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Epetra::Group > & object){ return object.total_count()  ; }

// LOCA::Abstract::TransposeSolveGroup
bool is_null(      Teuchos::RCP< LOCA::Abstract::TransposeSolveGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Abstract::TransposeSolveGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Abstract::TransposeSolveGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Abstract::TransposeSolveGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Abstract::TransposeSolveGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Abstract::TransposeSolveGroup > & object){ return object.total_count()  ; }

// LOCA::Abstract::Group
bool is_null(      Teuchos::RCP< LOCA::Abstract::Group > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Abstract::Group > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Abstract::Group > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Abstract::Group > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Abstract::Group > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Abstract::Group > & object){ return object.total_count()  ; }

// LOCA::PhaseTransition::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::PhaseTransition::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::PhaseTransition::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::PhaseTransition::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::PhaseTransition::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::PhaseTransition::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::PhaseTransition::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::Hopf::MinimallyAugmented::FiniteDifferenceGroup
bool is_null(      Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.total_count()  ; }

// LOCA::Hopf::MooreSpence::FiniteDifferenceGroup
bool is_null(      Teuchos::RCP< LOCA::Hopf::MooreSpence::FiniteDifferenceGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MooreSpence::FiniteDifferenceGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MooreSpence::FiniteDifferenceGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MooreSpence::FiniteDifferenceGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MooreSpence::FiniteDifferenceGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MooreSpence::FiniteDifferenceGroup > & object){ return object.total_count()  ; }

// LOCA::Hopf::MinimallyAugmented::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MinimallyAugmented::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::Hopf::MooreSpence::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::Hopf::MooreSpence::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Hopf::MooreSpence::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Hopf::MooreSpence::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Hopf::MooreSpence::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Hopf::MooreSpence::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Hopf::MooreSpence::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::TimeDependent::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::TimeDependent::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::TimeDependent::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::TimeDependent::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::TimeDependent::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::TimeDependent::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::TimeDependent::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::TurningPoint::MinimallyAugmented::FiniteDifferenceGroup
bool is_null(      Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::FiniteDifferenceGroup > & object){ return object.total_count()  ; }

// LOCA::TurningPoint::MooreSpence::FiniteDifferenceGroup
bool is_null(      Teuchos::RCP< LOCA::TurningPoint::MooreSpence::FiniteDifferenceGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::TurningPoint::MooreSpence::FiniteDifferenceGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::TurningPoint::MooreSpence::FiniteDifferenceGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::TurningPoint::MooreSpence::FiniteDifferenceGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::TurningPoint::MooreSpence::FiniteDifferenceGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::TurningPoint::MooreSpence::FiniteDifferenceGroup > & object){ return object.total_count()  ; }

// LOCA::MultiContinuation::FiniteDifferenceGroup
bool is_null(      Teuchos::RCP< LOCA::MultiContinuation::FiniteDifferenceGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::MultiContinuation::FiniteDifferenceGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::MultiContinuation::FiniteDifferenceGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::MultiContinuation::FiniteDifferenceGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::MultiContinuation::FiniteDifferenceGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::MultiContinuation::FiniteDifferenceGroup > & object){ return object.total_count()  ; }

// LOCA::Pitchfork::MinimallyAugmented::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::Pitchfork::MinimallyAugmented::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Pitchfork::MinimallyAugmented::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Pitchfork::MinimallyAugmented::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Pitchfork::MinimallyAugmented::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Pitchfork::MinimallyAugmented::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Pitchfork::MinimallyAugmented::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::Pitchfork::MooreSpence::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::Pitchfork::MooreSpence::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Pitchfork::MooreSpence::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Pitchfork::MooreSpence::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Pitchfork::MooreSpence::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Pitchfork::MooreSpence::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Pitchfork::MooreSpence::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::Homotopy::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::Homotopy::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::Homotopy::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::Homotopy::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::Homotopy::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::Homotopy::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::Homotopy::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::TurningPoint::MinimallyAugmented::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::TurningPoint::MinimallyAugmented::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::TurningPoint::MooreSpence::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::TurningPoint::MooreSpence::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::TurningPoint::MooreSpence::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::TurningPoint::MooreSpence::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::TurningPoint::MooreSpence::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::TurningPoint::MooreSpence::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::TurningPoint::MooreSpence::AbstractGroup > & object){ return object.total_count()  ; }

// LOCA::MultiContinuation::AbstractGroup
bool is_null(      Teuchos::RCP< LOCA::MultiContinuation::AbstractGroup > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< LOCA::MultiContinuation::AbstractGroup > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< LOCA::MultiContinuation::AbstractGroup > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< LOCA::MultiContinuation::AbstractGroup > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< LOCA::MultiContinuation::AbstractGroup > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< LOCA::MultiContinuation::AbstractGroup > & object){ return object.total_count()  ; }

// NOX::Epetra::Group
bool is_null(      Teuchos::RCP< NOX::Epetra::Group > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::Group > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::Group > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::Group > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::Group > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::Group > & object){ return object.total_count()  ; }

// NOX::Abstract::Group
bool is_null(      Teuchos::RCP< NOX::Abstract::Group > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Abstract::Group > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Abstract::Group > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Abstract::Group > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Abstract::Group > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Abstract::Group > & object){ return object.total_count()  ; }

// NOX::Epetra::Interface::Required
bool is_null(      Teuchos::RCP< NOX::Epetra::Interface::Required > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::Interface::Required > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::Interface::Required > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::Interface::Required > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::Interface::Required > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::Interface::Required > & object){ return object.total_count()  ; }

// NOX::Epetra::Interface::Jacobian
bool is_null(      Teuchos::RCP< NOX::Epetra::Interface::Jacobian > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::Interface::Jacobian > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::Interface::Jacobian > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::Interface::Jacobian > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::Interface::Jacobian > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::Interface::Jacobian > & object){ return object.total_count()  ; }

// NOX::Epetra::Interface::Preconditioner
bool is_null(      Teuchos::RCP< NOX::Epetra::Interface::Preconditioner > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::Epetra::Interface::Preconditioner > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::Epetra::Interface::Preconditioner > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::Epetra::Interface::Preconditioner > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::Epetra::Interface::Preconditioner > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::Epetra::Interface::Preconditioner > & object){ return object.total_count()  ; }

// NOX::StatusTest::Generic
bool is_null(      Teuchos::RCP< NOX::StatusTest::Generic > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< NOX::StatusTest::Generic > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< NOX::StatusTest::Generic > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< NOX::StatusTest::Generic > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< NOX::StatusTest::Generic > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< NOX::StatusTest::Generic > & object){ return object.total_count()  ; }

// Anasazi::OrthoManager<double, Epetra_MultiVector>
bool is_null(      Teuchos::RCP< Anasazi::OrthoManager<double, Epetra_MultiVector> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::OrthoManager<double, Epetra_MultiVector> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::OrthoManager<double, Epetra_MultiVector> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::OrthoManager<double, Epetra_MultiVector> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::OrthoManager<double, Epetra_MultiVector> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::OrthoManager<double, Epetra_MultiVector> > & object){ return object.total_count()  ; }

// Anasazi::Eigenproblem<double, Epetra_MultiVector, Epetra_Operator>
bool is_null(      Teuchos::RCP< Anasazi::Eigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::Eigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::Eigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::Eigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::Eigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::Eigenproblem<double, Epetra_MultiVector, Epetra_Operator> > & object){ return object.total_count()  ; }

// Anasazi::SortManager<double>
bool is_null(      Teuchos::RCP< Anasazi::SortManager<double> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::SortManager<double> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::SortManager<double> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::SortManager<double> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::SortManager<double> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::SortManager<double> > & object){ return object.total_count()  ; }

// Anasazi::OutputManager<double>
bool is_null(      Teuchos::RCP< Anasazi::OutputManager<double> > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Anasazi::OutputManager<double> > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Anasazi::OutputManager<double> > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Anasazi::OutputManager<double> > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Anasazi::OutputManager<double> > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Anasazi::OutputManager<double> > & object){ return object.total_count()  ; }

// Ifpack_Preconditioner
bool is_null(      Teuchos::RCP< Ifpack_Preconditioner > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Ifpack_Preconditioner > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Ifpack_Preconditioner > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Ifpack_Preconditioner > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Ifpack_Preconditioner > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Ifpack_Preconditioner > & object){ return object.total_count()  ; }

// Isorropia::Epetra::Operator
bool is_null(      Teuchos::RCP< Isorropia::Epetra::Operator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Epetra::Operator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Epetra::Operator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Epetra::Operator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Epetra::Operator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Epetra::Operator > & object){ return object.total_count()  ; }

// Isorropia::LevelScheduler
bool is_null(      Teuchos::RCP< Isorropia::LevelScheduler > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::LevelScheduler > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::LevelScheduler > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::LevelScheduler > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::LevelScheduler > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::LevelScheduler > & object){ return object.total_count()  ; }

// Isorropia::Orderer
bool is_null(      Teuchos::RCP< Isorropia::Orderer > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Orderer > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Orderer > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Orderer > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Orderer > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Orderer > & object){ return object.total_count()  ; }

// Isorropia::Redistributor
bool is_null(      Teuchos::RCP< Isorropia::Redistributor > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Redistributor > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Redistributor > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Redistributor > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Redistributor > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Redistributor > & object){ return object.total_count()  ; }

// Isorropia::Partitioner
bool is_null(      Teuchos::RCP< Isorropia::Partitioner > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Partitioner > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Partitioner > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Partitioner > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Partitioner > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Partitioner > & object){ return object.total_count()  ; }

// Isorropia::Operator
bool is_null(      Teuchos::RCP< Isorropia::Operator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Isorropia::Operator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Isorropia::Operator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Isorropia::Operator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Isorropia::Operator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Isorropia::Operator > & object){ return object.total_count()  ; }

// Epetra_VbrMatrix
bool is_null(      Teuchos::RCP< Epetra_VbrMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_VbrMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_VbrMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_VbrMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_VbrMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_VbrMatrix > & object){ return object.total_count()  ; }

// Epetra_RowMatrix
bool is_null(      Teuchos::RCP< Epetra_RowMatrix > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_RowMatrix > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_RowMatrix > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_RowMatrix > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_RowMatrix > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_RowMatrix > & object){ return object.total_count()  ; }

// Epetra_Operator
bool is_null(      Teuchos::RCP< Epetra_Operator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Operator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Operator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Operator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Operator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Operator > & object){ return object.total_count()  ; }

// Epetra_SerialDenseOperator
bool is_null(      Teuchos::RCP< Epetra_SerialDenseOperator > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SerialDenseOperator > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SerialDenseOperator > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SerialDenseOperator > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SerialDenseOperator > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SerialDenseOperator > & object){ return object.total_count()  ; }

// Epetra_MultiVector
bool is_null(      Teuchos::RCP< Epetra_MultiVector > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_MultiVector > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_MultiVector > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_MultiVector > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_MultiVector > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_MultiVector > & object){ return object.total_count()  ; }

// Epetra_BLAS
bool is_null(      Teuchos::RCP< Epetra_BLAS > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_BLAS > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_BLAS > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_BLAS > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_BLAS > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_BLAS > & object){ return object.total_count()  ; }

// Epetra_Map
bool is_null(      Teuchos::RCP< Epetra_Map > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Map > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Map > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Map > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Map > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Map > & object){ return object.total_count()  ; }

// Epetra_BlockMap
bool is_null(      Teuchos::RCP< Epetra_BlockMap > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_BlockMap > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_BlockMap > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_BlockMap > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_BlockMap > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_BlockMap > & object){ return object.total_count()  ; }

// Epetra_DistObject
bool is_null(      Teuchos::RCP< Epetra_DistObject > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_DistObject > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_DistObject > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_DistObject > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_DistObject > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_DistObject > & object){ return object.total_count()  ; }

// Epetra_SrcDistObject
bool is_null(      Teuchos::RCP< Epetra_SrcDistObject > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_SrcDistObject > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_SrcDistObject > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_SrcDistObject > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_SrcDistObject > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_SrcDistObject > & object){ return object.total_count()  ; }

// Epetra_CompObject
bool is_null(      Teuchos::RCP< Epetra_CompObject > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_CompObject > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_CompObject > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_CompObject > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_CompObject > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_CompObject > & object){ return object.total_count()  ; }

// Epetra_Object
bool is_null(      Teuchos::RCP< Epetra_Object > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Epetra_Object > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Epetra_Object > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Epetra_Object > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Epetra_Object > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Epetra_Object > & object){ return object.total_count()  ; }

// Teuchos::Describable
bool is_null(      Teuchos::RCP< Teuchos::Describable > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::Describable > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::Describable > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::Describable > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::Describable > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::Describable > & object){ return object.total_count()  ; }

// Teuchos::LabeledObject
bool is_null(      Teuchos::RCP< Teuchos::LabeledObject > & object){ return object.is_null()      ; }
bool is_valid_ptr( Teuchos::RCP< Teuchos::LabeledObject > & object){ return object.is_valid_ptr() ; }
bool has_ownership(Teuchos::RCP< Teuchos::LabeledObject > & object){ return object.has_ownership(); }
int  strong_count( Teuchos::RCP< Teuchos::LabeledObject > & object){ return object.strong_count() ; }
int  weak_count(   Teuchos::RCP< Teuchos::LabeledObject > & object){ return object.weak_count()   ; }
int  total_count(  Teuchos::RCP< Teuchos::LabeledObject > & object){ return object.total_count()  ; }

}
